| load_sample_seurat | R Documentation |
Loads the sample_seurat example dataset for testing the scToNeb function. This dataset contains a subset (1000 genes and 1000 cells) of the eight-pancreas scRNA-seq datasets.
load_sample_seurat()
Load sample_seurat data
This function requires the Seurat package to be installed. If Seurat is not available, the function will throw an error with installation instructions.
A Seurat object containing example single-cell data
scToNeb
## Not run:
library(nebula)
sample_seurat <- load_sample_seurat()
re <- scToNeb(obj = sample_seurat, assay = "RNA", id = "replicate",
pred = c("celltype", "tech"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.