Learn R Programming

nebula (version 1.5.6)

nebula-package: tools:::Rd_package_title("nebula")

Description

tools:::Rd_package_description("nebula")

Arguments

Author

tools:::Rd_package_author("nebula")

Maintainer: tools:::Rd_package_maintainer("nebula")

Details

nebula is an R package for performing association analysis using a fast negative binomial mixed model for multi-subject single-cell data.

References

He, L., Davila-Velderrain, J., Sumida, T. S., Hafler, D. A., Kellis, M., & Kulminski, A. M. (2021). NEBULA is a fast negative binomial mixed model for differential or co-expression analysis of large-scale multi-subject single-cell data. Communications biology, 4(1), 1-17.

Examples

Run this code
library(nebula)
data(sample_data)
pred = model.matrix(~X1+X2+cc,data=sample_data$pred)
re = nebula(count=sample_data$count,id=sample_data$sid,pred=pred)

Run the code above in your browser using DataLab