| scToNeb | R Documentation |
Extracts count matrix and metadata from Seurat or SingleCellExperiment objects and formats them for use with the nebula function. Handles predictors, sample IDs, and offset factors.
scToNeb(
obj,
assay = NULL,
id = NULL,
pred = NULL,
offset = NULL,
verbose = TRUE
)
obj |
|
assay |
Assay to retrieve counts from the corresponding |
id |
Sample ID to use metadata object i.e. |
pred |
Character vector of predictors from metadata in |
offset |
Metadata column corresponding to per-cell scaling factor e.g. TMM. |
verbose |
Indicating whether to print additional messages. |
Retrieve data from Seurat or SingleCellExperiment object to prepare for use in nebula
data_neb: A list usable for nebula.
## Not run:
library(Seurat)
library(nebula)
sample_seurat <- load_sample_seurat()
re <- scToNeb(obj = sample_seurat, assay = "RNA", id = "replicate", pred = c("celltype", "tech"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.